pub enum WorktreeEntryState {
Clean,
Modified,
Deleted,
}Expand description
The worktree state of one tracked path relative to an expected index/tree entry.
Variants
Clean
The path exists in the worktree and matches the expected mode/object id.
Modified
The path exists, but its type, mode, filtered content, symlink target, or gitlink HEAD differs from the expected entry.
Deleted
The path, or one of its parents, is missing from the worktree.