ApplySparseResult

Struct ApplySparseResult 

pub struct ApplySparseResult {
    pub materialized: Vec<Vec<u8>>,
    pub skipped: Vec<Vec<u8>>,
    pub not_up_to_date: Vec<Vec<u8>>,
}

Fields

materialized: Vec<Vec<u8>>

Paths whose worktree file was (re)materialized because they are in cone.

skipped: Vec<Vec<u8>>

Paths that were taken out of the worktree because they are out of cone; their index entry now has the skip-worktree bit set.

not_up_to_date: Vec<Vec<u8>>

Out-of-cone paths whose worktree file was not up to date with the index and was therefore left in place (and its skip-worktree bit left clear), matching git’s data-loss-avoiding behavior. The caller surfaces these as git’s “The following paths are not up to date …” warning. Sorted by path.